xsdata.formats.dataclass.serializers package
============================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass.serializers.json
   xsdata.formats.dataclass.serializers.utils
   xsdata.formats.dataclass.serializers.xml

Module contents
---------------

.. automodule:: xsdata.formats.dataclass.serializers
   :members:
   :undoc-members:
   :show-inheritance:
